@@ -1,5 +1,5 @@
 
-#include <cmpinclude.h>
+#include "cmpinclude.h"
 #include "cmploc.h"
 init_cmploc(){do_init(VV);}
 /*	local entry for function WT-NEXT-VAR-ARG	*/
@@ -225,42 +225,37 @@ register object V11;
 {	 VMB4 VMS4 VMV4
 TTL:;
 	{object V12;
-	base[0]= (V11);
-	base[1]= VV[7];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V12= vs_base[0];
+	V12= (((V11))==(VV[7])?Ct:Cnil);
 	if(((V12))==Cnil){
-	goto T103;}
+	goto T101;}
 	{object V13 = (V12);
 	VMR4(V13)}
-T103:;
+T101:;
 	if(!(type_of((V11))==t_cons)){
-	goto T106;}
+	goto T104;}
 	if(!((car((V11)))==(VV[14]))){
-	goto T106;}
+	goto T104;}
 	if(!(number_compare(caadr((V11)),symbol_value(VV[15]))==0)){
-	goto T106;}
+	goto T104;}
 	princ_str("\n	vs_top=(vs_base=base+",VV[0]);
 	(void)((*(LnkLI36))(cdadr((V11))));
 	princ_str(")+1;",VV[0]);
 	setq(VV[16],Ct);
 	{object V14 = Ct;
 	VMR4(V14)}
-T106:;
+T104:;
 	if(!(type_of((V11))==t_cons)){
-	goto T118;}
+	goto T116;}
 	if(!((car((V11)))==(VV[17]))){
-	goto T118;}
+	goto T116;}
 	V15= structure_ref(cadr((V11)),VV[17],1);
 	if(!((/* INLINE-ARGS */V15)==(VV[18]))){
-	goto T118;}
+	goto T116;}
 	if((structure_ref(cadr((V11)),VV[17],3))!=Cnil){
-	goto T118;}
+	goto T116;}
 	V16= structure_ref(cadr((V11)),VV[17],2);
 	if(!(eql(car(/* INLINE-ARGS */V16),symbol_value(VV[15])))){
-	goto T118;}
+	goto T116;}
 	princ_str("\n	vs_top=(vs_base=base+",VV[0]);
 	V17= structure_ref(cadr((V11)),VV[17],2);
 	(void)((*(LnkLI36))(cdr(/* INLINE-ARGS */V17)));
@@ -268,7 +263,7 @@ T106:;
 	setq(VV[16],Ct);
 	{object V18 = Ct;
 	VMR4(V18)}
-T118:;
+T116:;
 	{object V19 = (*(LnkLI37))((V11));
 	VMR4(V19)}}
 }
@@ -282,8 +277,8 @@ object V21;
 TTL:;
 	bds_bind(VV[19],symbol_value(VV[19]));
 	princ_str("\n	",VV[0]);
-	V22= (*(LnkLI45))();
-	(void)((*(LnkLI44))(/* INLINE-ARGS */V22));
+	V22= (*(LnkLI44))();
+	(void)((*(LnkLI43))(/* INLINE-ARGS */V22));
 	princ_str("= ",VV[0]);
 	(void)((*(LnkLI36))((V21)));
 	princ_char(59,VV[0]);
@@ -361,21 +356,21 @@ static object LI10(V37,va_alist)
 	if(narg <1) too_few_arguments();
 	V38= V37;
 	narg = narg - 1;
-	if (narg <= 0) goto T156;
+	if (narg <= 0) goto T154;
 	else {
 	va_start(ap);
 	V39= va_arg(ap,object);}
-	--narg; goto T157;
-T156:;
+	--narg; goto T155;
+T154:;
 	V39= Cnil;
-T157:;
+T155:;
 	if(((V39))==Cnil){
-	goto T159;}
+	goto T157;}
 	princ_str("/* ",VV[0]);
 	V40= symbol_name((V39));
 	(void)((*(LnkLI36))(/* INLINE-ARGS */V40));
 	princ_str(" */",VV[0]);
-T159:;
+T157:;
 	princ_char(86,VV[0]);
 	(void)((*(LnkLI36))((V38)));
 	{object V41 = Cnil;
@@ -406,58 +401,58 @@ static L12()
 	vs_top=sup;
 TTL:;
 	if(!(type_of((V45))==t_cons)){
-	goto T171;}
+	goto T169;}
 	if(!((car((V45)))==(VV[17]))){
-	goto T171;}
+	goto T169;}
 	V46= structure_ref(cadr((V45)),VV[17],1);
 	if(!((/* INLINE-ARGS */V46)==(VV[20]))){
-	goto T171;}
+	goto T169;}
 	princ_char(86,VV[0]);
 	V47= structure_ref(cadr((V45)),VV[17],4);
 	(void)((*(LnkLI36))(/* INLINE-ARGS */V47));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T171:;
+T169:;
 	if(!(type_of((V45))==t_cons)){
-	goto T180;}
+	goto T178;}
 	if(!((car((V45)))==(VV[21]))){
-	goto T180;}
+	goto T178;}
 	base[1]= caddr((V45));
 	base[2]= cadddr((V45));
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	return;
-T180:;
+T178:;
 	if(!(type_of((V45))==t_cons)){
-	goto T187;}
+	goto T185;}
 	if(!((car((V45)))==(VV[22]))){
-	goto T187;}
+	goto T185;}
 	(void)((*(LnkLI36))(caddr((V45))));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T187:;
+T185:;
 	if(!(type_of((V45))==t_cons)){
-	goto T193;}
+	goto T191;}
 	{register object x= car((V45)),V48= VV[23];
 	while(!endp(V48))
 	if(eql(x,V48->c.c_car)){
-	goto T196;
+	goto T194;
 	}else V48=V48->c.c_cdr;
-	goto T193;}
-T196:;
+	goto T191;}
+T194:;
 	princ_str("((int)(",VV[0]);
 	base[1]= caddr((V45));
 	base[2]= cadddr((V45));
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	vs_top=sup;
 	princ_str("))",VV[0]);
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T193:;
+T191:;
 	princ_str("fix(",VV[0]);
 	(void)((*(LnkLI36))((V45)));
 	princ_char(41,VV[0]);
@@ -478,94 +473,86 @@ static L13()
 	if(vs_top-vs_base>2) too_many_arguments();
 	V49=(base[0]);
 	vs_base=vs_base+1;
-	if(vs_base>=vs_top){vs_top=sup;goto T206;}
+	if(vs_base>=vs_top){vs_top=sup;goto T204;}
 	V50=(base[1]);
 	vs_top=sup;
-	goto T207;
-T206:;
+	goto T205;
+T204:;
 	V50= Cnil;
-T207:;
+T205:;
 	{object V51;
 	object V52;
 	V51= Ct;
-	base[3]= (V49);
-	vs_top=(vs_base=base+3)+1;
-	(void) (*Lnk47)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T211;}
+	if(type_of((V49))==t_cons){
+	goto T209;}
 	V52= Cnil;
-	goto T210;
-T211:;
+	goto T208;
+T209:;
 	V52= car((V49));
-T210:;
+T208:;
 	{object V53= (V52);
-	if((V53!= VV[21]))goto T215;
+	if((V53!= VV[21]))goto T212;
 	princ_str("stoi(",VV[0]);
 	base[3]= caddr((V49));
 	base[4]= cadddr((V49));
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	vs_top=sup;
 	princ_char(41,VV[0]);
-	goto T214;
-T215:;
-	if((V53!= VV[48]))goto T222;
+	goto T211;
+T212:;
+	if((V53!= VV[46]))goto T219;
 	V51= Cnil;
 	base[3]= caddr((V49));
 	base[4]= cadddr((V49));
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	vs_top=sup;
-	goto T214;
-T222:;
-	if((V53!= VV[22]))goto T227;
+	goto T211;
+T219:;
+	if((V53!= VV[22]))goto T224;
 	princ_str("stoi(",VV[0]);
 	(void)((*(LnkLI36))(caddr((V49))));
 	princ_char(41,VV[0]);
-	goto T214;
-T227:;
-	if((V53!= VV[17]))goto T231;
+	goto T211;
+T224:;
+	if((V53!= VV[17]))goto T228;
 	V55= structure_ref(cadr((V49)),VV[17],1);
 	{object V54= /* INLINE-ARGS */V55;
-	if((V54!= VV[49]))goto T232;
+	if((V54!= VV[47]))goto T229;
 	V51= Cnil;
 	princ_char(86,VV[0]);
 	V56= structure_ref(cadr((V49)),VV[17],4);
 	(void)((*(LnkLI36))(/* INLINE-ARGS */V56));
-	goto T214;
-T232:;
-	if((V54!= VV[20]))goto T237;
+	goto T211;
+T229:;
+	if((V54!= VV[20]))goto T234;
 	princ_str("stoi(V",VV[0]);
 	V57= structure_ref(cadr((V49)),VV[17],4);
 	(void)((*(LnkLI36))(/* INLINE-ARGS */V57));
 	princ_char(41,VV[0]);
-	goto T214;
-T237:;
+	goto T211;
+T234:;
 	princ_str("otoi(",VV[0]);
 	(void)((*(LnkLI36))((V49)));
 	princ_char(41,VV[0]);
-	goto T214;}
-T231:;
+	goto T211;}
+T228:;
 	princ_str("otoi(",VV[0]);
 	(void)((*(LnkLI36))((V49)));
 	princ_char(41,VV[0]);}
-T214:;
+T211:;
 	if((V51)==Cnil){
 	base[3]= Cnil;
 	vs_top=(vs_base=base+3)+1;
 	return;}
-	base[3]= symbol_value(VV[24]);
-	vs_top=(vs_base=base+3)+1;
-	(void) (*Lnk50)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T247;}
+	if((symbol_value(VV[24]))==Cnil){
+	goto T244;}
 	base[3]= Cnil;
 	vs_top=(vs_base=base+3)+1;
 	return;
-T247:;
-	base[3]= (*(LnkLI51))();
+T244:;
+	base[3]= (*(LnkLI48))();
 	vs_top=(vs_base=base+3)+1;
 	return;}
 	}
@@ -577,52 +564,29 @@ static object LI14(V59)
 register object V59;
 {	 VMB14 VMS14 VMV14
 TTL:;
-	base[0]= (V59);
-	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk47)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T250;}
+	if(type_of((V59))==t_cons){
+	goto T246;}
 	{object V60 = Cnil;
 	VMR14(V60)}
-T250:;{object V61;
-	base[0]= car((V59));
-	base[1]= VV[17];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T255;}
+T246:;{object V61;
+	if((car((V59)))==(VV[17])){
+	goto T250;}
 	V61= Cnil;
-	goto T254;
-T255:;
-	base[0]= structure_ref(cadr((V59)),VV[17],1);
-	base[1]= VV[20];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V61= vs_base[0];
-T254:;
-	if(V61==Cnil)goto T253;
-	{object V62 = V61;
-	VMR14(V62)}
-T253:;}{object V63;
-	base[0]= car((V59));
-	base[1]= VV[21];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V63= vs_base[0];
-	if(V63==Cnil)goto T261;
-	{object V64 = V63;
+	goto T249;
+T250:;
+	V62= structure_ref(cadr((V59)),VV[17],1);
+	V61= ((/* INLINE-ARGS */V62)==(VV[20])?Ct:Cnil);
+T249:;
+	if(V61==Cnil)goto T248;
+	{object V63 = V61;
+	VMR14(V63)}
+T248:;}
+	if(!((car((V59)))==(VV[21]))){
+	goto T252;}
+	{object V64 = Ct;
 	VMR14(V64)}
-T261:;}
-	base[0]= car((V59));
-	base[1]= VV[22];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	{object V65 = vs_base[0];
+T252:;
+	{object V65 = ((car((V59)))==(VV[22])?Ct:Cnil);
 	VMR14(V65)}
 }
 /*	local entry for function WT-FIXNUM-VALUE	*/
@@ -633,13 +597,13 @@ object V68;object V69;
 {	 VMB15 VMS15 VMV15
 TTL:;
 	if(((V68))==Cnil){
-	goto T268;}
+	goto T255;}
 	princ_str("VV[",VV[0]);
 	(void)((*(LnkLI36))((V68)));
 	princ_char(93,VV[0]);
 	{object V70 = Cnil;
 	VMR15(V70)}
-T268:;
+T255:;
 	princ_str("small_fixnum(",VV[0]);
 	(void)((*(LnkLI36))((V69)));
 	princ_char(41,VV[0]);
@@ -658,38 +622,38 @@ static L16()
 	vs_top=sup;
 TTL:;
 	if(!(type_of((V72))==t_cons)){
-	goto T277;}
+	goto T264;}
 	if(!((car((V72)))==(VV[17]))){
-	goto T277;}
+	goto T264;}
 	V73= structure_ref(cadr((V72)),VV[17],1);
 	if(!((/* INLINE-ARGS */V73)==(VV[25]))){
-	goto T277;}
+	goto T264;}
 	princ_char(86,VV[0]);
 	V74= structure_ref(cadr((V72)),VV[17],4);
 	(void)((*(LnkLI36))(/* INLINE-ARGS */V74));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T277:;
+T264:;
 	if(!(type_of((V72))==t_cons)){
-	goto T286;}
+	goto T273;}
 	if(!((car((V72)))==(VV[26]))){
-	goto T286;}
+	goto T273;}
 	base[1]= caddr((V72));
 	base[2]= cadddr((V72));
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	return;
-T286:;
+T273:;
 	if(!(type_of((V72))==t_cons)){
-	goto T293;}
+	goto T280;}
 	if(!((car((V72)))==(VV[27]))){
-	goto T293;}
+	goto T280;}
 	(void)((*(LnkLI36))(caddr((V72))));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T293:;
+T280:;
 	princ_str("char_code(",VV[0]);
 	(void)((*(LnkLI36))((V72)));
 	princ_char(41,VV[0]);
@@ -705,52 +669,29 @@ static object LI17(V76)
 register object V76;
 {	 VMB17 VMS17 VMV17
 TTL:;
-	base[0]= (V76);
-	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk47)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T301;}
+	if(type_of((V76))==t_cons){
+	goto T288;}
 	{object V77 = Cnil;
 	VMR17(V77)}
-T301:;{object V78;
-	base[0]= car((V76));
-	base[1]= VV[17];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T306;}
+T288:;{object V78;
+	if((car((V76)))==(VV[17])){
+	goto T292;}
 	V78= Cnil;
-	goto T305;
-T306:;
-	base[0]= structure_ref(cadr((V76)),VV[17],1);
-	base[1]= VV[25];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V78= vs_base[0];
-T305:;
-	if(V78==Cnil)goto T304;
-	{object V79 = V78;
-	VMR17(V79)}
-T304:;}{object V80;
-	base[0]= car((V76));
-	base[1]= VV[26];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V80= vs_base[0];
-	if(V80==Cnil)goto T312;
-	{object V81 = V80;
+	goto T291;
+T292:;
+	V79= structure_ref(cadr((V76)),VV[17],1);
+	V78= ((/* INLINE-ARGS */V79)==(VV[25])?Ct:Cnil);
+T291:;
+	if(V78==Cnil)goto T290;
+	{object V80 = V78;
+	VMR17(V80)}
+T290:;}
+	if(!((car((V76)))==(VV[26]))){
+	goto T294;}
+	{object V81 = Ct;
 	VMR17(V81)}
-T312:;}
-	base[0]= car((V76));
-	base[1]= VV[27];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	{object V82 = vs_base[0];
+T294:;
+	{object V82 = ((car((V76)))==(VV[27])?Ct:Cnil);
 	VMR17(V82)}
 }
 /*	local entry for function WT-CHARACTER-VALUE	*/
@@ -778,38 +719,38 @@ static L19()
 	vs_top=sup;
 TTL:;
 	if(!(type_of((V88))==t_cons)){
-	goto T322;}
+	goto T300;}
 	if(!((car((V88)))==(VV[17]))){
-	goto T322;}
+	goto T300;}
 	V89= structure_ref(cadr((V88)),VV[17],1);
 	if(!((/* INLINE-ARGS */V89)==(VV[28]))){
-	goto T322;}
+	goto T300;}
 	princ_char(86,VV[0]);
 	V90= structure_ref(cadr((V88)),VV[17],4);
 	(void)((*(LnkLI36))(/* INLINE-ARGS */V90));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T322:;
+T300:;
 	if(!(type_of((V88))==t_cons)){
-	goto T331;}
+	goto T309;}
 	if(!((car((V88)))==(VV[29]))){
-	goto T331;}
+	goto T309;}
 	base[1]= caddr((V88));
 	base[2]= cadddr((V88));
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	return;
-T331:;
+T309:;
 	if(!(type_of((V88))==t_cons)){
-	goto T338;}
+	goto T316;}
 	if(!((car((V88)))==(VV[30]))){
-	goto T338;}
+	goto T316;}
 	(void)((*(LnkLI36))(caddr((V88))));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T338:;
+T316:;
 	princ_str("lf(",VV[0]);
 	(void)((*(LnkLI36))((V88)));
 	princ_char(41,VV[0]);
@@ -825,52 +766,29 @@ static object LI20(V92)
 register object V92;
 {	 VMB20 VMS20 VMV20
 TTL:;
-	base[0]= (V92);
-	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk47)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T346;}
+	if(type_of((V92))==t_cons){
+	goto T324;}
 	{object V93 = Cnil;
 	VMR20(V93)}
-T346:;{object V94;
-	base[0]= car((V92));
-	base[1]= VV[17];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T351;}
+T324:;{object V94;
+	if((car((V92)))==(VV[17])){
+	goto T328;}
 	V94= Cnil;
-	goto T350;
-T351:;
-	base[0]= structure_ref(cadr((V92)),VV[17],1);
-	base[1]= VV[28];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V94= vs_base[0];
-T350:;
-	if(V94==Cnil)goto T349;
-	{object V95 = V94;
-	VMR20(V95)}
-T349:;}{object V96;
-	base[0]= car((V92));
-	base[1]= VV[29];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V96= vs_base[0];
-	if(V96==Cnil)goto T357;
-	{object V97 = V96;
+	goto T327;
+T328:;
+	V95= structure_ref(cadr((V92)),VV[17],1);
+	V94= ((/* INLINE-ARGS */V95)==(VV[28])?Ct:Cnil);
+T327:;
+	if(V94==Cnil)goto T326;
+	{object V96 = V94;
+	VMR20(V96)}
+T326:;}
+	if(!((car((V92)))==(VV[29]))){
+	goto T330;}
+	{object V97 = Ct;
 	VMR20(V97)}
-T357:;}
-	base[0]= car((V92));
-	base[1]= VV[30];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	{object V98 = vs_base[0];
+T330:;
+	{object V98 = ((car((V92)))==(VV[30])?Ct:Cnil);
 	VMR20(V98)}
 }
 /*	local entry for function WT-LONG-FLOAT-VALUE	*/
@@ -898,38 +816,38 @@ static L22()
 	vs_top=sup;
 TTL:;
 	if(!(type_of((V104))==t_cons)){
-	goto T367;}
+	goto T336;}
 	if(!((car((V104)))==(VV[17]))){
-	goto T367;}
+	goto T336;}
 	V105= structure_ref(cadr((V104)),VV[17],1);
 	if(!((/* INLINE-ARGS */V105)==(VV[31]))){
-	goto T367;}
+	goto T336;}
 	princ_char(86,VV[0]);
 	V106= structure_ref(cadr((V104)),VV[17],4);
 	(void)((*(LnkLI36))(/* INLINE-ARGS */V106));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T367:;
+T336:;
 	if(!(type_of((V104))==t_cons)){
-	goto T376;}
+	goto T345;}
 	if(!((car((V104)))==(VV[32]))){
-	goto T376;}
+	goto T345;}
 	base[1]= caddr((V104));
 	base[2]= cadddr((V104));
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	return;
-T376:;
+T345:;
 	if(!(type_of((V104))==t_cons)){
-	goto T383;}
+	goto T352;}
 	if(!((car((V104)))==(VV[33]))){
-	goto T383;}
+	goto T352;}
 	(void)((*(LnkLI36))(caddr((V104))));
 	base[1]= Cnil;
 	vs_top=(vs_base=base+1)+1;
 	return;
-T383:;
+T352:;
 	princ_str("sf(",VV[0]);
 	(void)((*(LnkLI36))((V104)));
 	princ_char(41,VV[0]);
@@ -945,52 +863,29 @@ static object LI23(V108)
 register object V108;
 {	 VMB23 VMS23 VMV23
 TTL:;
-	base[0]= (V108);
-	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk47)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T391;}
+	if(type_of((V108))==t_cons){
+	goto T360;}
 	{object V109 = Cnil;
 	VMR23(V109)}
-T391:;{object V110;
-	base[0]= car((V108));
-	base[1]= VV[17];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	if((vs_base[0])!=Cnil){
-	goto T396;}
+T360:;{object V110;
+	if((car((V108)))==(VV[17])){
+	goto T364;}
 	V110= Cnil;
-	goto T395;
-T396:;
-	base[0]= structure_ref(cadr((V108)),VV[17],1);
-	base[1]= VV[31];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V110= vs_base[0];
-T395:;
-	if(V110==Cnil)goto T394;
-	{object V111 = V110;
-	VMR23(V111)}
-T394:;}{object V112;
-	base[0]= car((V108));
-	base[1]= VV[32];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	V112= vs_base[0];
-	if(V112==Cnil)goto T402;
-	{object V113 = V112;
+	goto T363;
+T364:;
+	V111= structure_ref(cadr((V108)),VV[17],1);
+	V110= ((/* INLINE-ARGS */V111)==(VV[31])?Ct:Cnil);
+T363:;
+	if(V110==Cnil)goto T362;
+	{object V112 = V110;
+	VMR23(V112)}
+T362:;}
+	if(!((car((V108)))==(VV[32]))){
+	goto T366;}
+	{object V113 = Ct;
 	VMR23(V113)}
-T402:;}
-	base[0]= car((V108));
-	base[1]= VV[33];
-	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
-	vs_top=sup;
-	{object V114 = vs_base[0];
+T366:;
+	{object V114 = ((car((V108)))==(VV[33])?Ct:Cnil);
 	VMR23(V114)}
 }
 /*	local entry for function WT-SHORT-FLOAT-VALUE	*/
@@ -1006,13 +901,10 @@ TTL:;
 	{object V119 = Cnil;
 	VMR24(V119)}
 }
-static object  LnkTLI51(){return call_proc0(VV[51],&LnkLI51);} /* WFS-ERROR */
-static LnkT50(){ call_or_link(VV[50],&Lnk50);} /* NOT */
-static LnkT47(){ call_or_link(VV[47],&Lnk47);} /* CONSP */
-static LnkT46(){ call_or_link(VV[46],&Lnk46);} /* WT-INLINE-LOC */
-static object  LnkTLI45(){return call_proc0(VV[45],&LnkLI45);} /* VS-PUSH */
-static object  LnkTLI44(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[44],&LnkLI44,1,ap);} /* WT-VS */
-static LnkT43(){ call_or_link(VV[43],&Lnk43);} /* EQ */
+static object  LnkTLI48(){return call_proc0(VV[48],&LnkLI48);} /* WFS-ERROR */
+static LnkT45(){ call_or_link(VV[45],&Lnk45);} /* WT-INLINE-LOC */
+static object  LnkTLI44(){return call_proc0(VV[44],&LnkLI44);} /* VS-PUSH */
+static object  LnkTLI43(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[43],&LnkLI43,1,ap);} /* WT-VS */
 static object  LnkTLI42(){return call_proc0(VV[42],&LnkLI42);} /* BABOON */
 static LnkT41(){ call_or_link(VV[41],&Lnk41);} /* SET-RETURN-SHORT-FLOAT */
 static LnkT40(){ call_or_link(VV[40],&Lnk40);} /* SET-RETURN-LONG-FLOAT */
