@@ -1,5 +1,5 @@
 
-#include <cmpinclude.h>
+#include "cmpinclude.h"
 #include "cmpwt.h"
 init_cmpwt(){do_init(VV);}
 /*	local entry for function WT-COMMENT	*/
@@ -43,7 +43,7 @@ T14:;
 	base[0]= code_char(V7);
 	base[1]= VV[1];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk43)();
+	Lchar_eq();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T18;}
@@ -82,13 +82,13 @@ T36:;
 	base[1]= VV[2];
 	base[2]= (V10);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk44)();
+	Lformat();
 	vs_top=sup;
 	goto T28;
 T37:;
 	base[0]= (V10);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk45)();
+	(void) (*Lnk43)();
 	vs_top=sup;
 T28:;
 	{object V11 = Cnil;
@@ -121,7 +121,7 @@ T51:;
 	base[0]= VV[4];
 	base[1]= (V13);
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk44)();
 	vs_top=sup;
 	goto T45;}
 T47:;
@@ -140,11 +140,11 @@ TTL:;
 	base[0]= (V18);
 	base[1]= small_fixnum(-1000);
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk48)();
+	(void) (*Lnk46)();
 	vs_top=sup;
 	V19= vs_base[0];
 	V20= make_cons(V19,(V18));
-	(void)((VFUN_NARGS=2,(*(LnkLI47))(/* INLINE-ARGS */V20,car(symbol_value(VV[6])))));
+	(void)((VFUN_NARGS=2,(*(LnkLI45))(/* INLINE-ARGS */V20,car(symbol_value(VV[6])))));
 	setq(VV[7],number_plus(symbol_value(VV[7]),small_fixnum(1)));
 	{object V21 = symbol_value(VV[7]);
 	VMR4(V21)}
@@ -208,12 +208,12 @@ T69:;
 	base[1]= cdr((V27));
 	base[2]= small_fixnum(-1000);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk48)();
+	(void) (*Lnk46)();
 	vs_top=sup;
 	V30= vs_base[0];
 	if(eql(car((V27)),(V30))){
 	goto T75;}
-	(void)((VFUN_NARGS=2,(*(LnkLI49))(VV[22],cdr((V27)))));}
+	(void)((VFUN_NARGS=2,(*(LnkLI47))(VV[22],cdr((V27)))));}
 T75:;
 	(void)(aset1((V26),fixint((V29)),cdr((V27))));
 	V29= one_plus((V29));
@@ -247,7 +247,7 @@ T86:;
 	base[0]= (V33);
 	base[1]= small_fixnum(-1000);
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk48)();
+	(void) (*Lnk46)();
 	vs_top=sup;
 	V36= vs_base[0];
 	V35= make_cons(V36,(V33));
@@ -278,11 +278,11 @@ static L8()
 	check_arg(0);
 	vs_top=sup;
 TTL:;
-	(void)((*(LnkLI50))(car(symbol_value(VV[6]))));
+	(void)((*(LnkLI48))(car(symbol_value(VV[6]))));
 	{object V42;
 	V43= nreverse(cadr(symbol_value(VV[6])));
-	V42= (*(LnkLI51))(/* INLINE-ARGS */V43,VV[23]);
-	(void)((*(LnkLI50))((V42)));
+	V42= (*(LnkLI49))(/* INLINE-ARGS */V43,VV[23]);
+	(void)((*(LnkLI48))((V42)));
 	V44= car(symbol_value(VV[6]));
 	V45 = make_fixnum(length(car(symbol_value(VV[6]))));
 	V46= number_minus(V45,small_fixnum(1));
@@ -298,13 +298,13 @@ TTL:;
 	if((symbol_value(VV[25]))==Cnil){
 	goto T108;}
 	vs_base=vs_top;
-	(void) (*Lnk52)();
+	(void) (*Lnk50)();
 	return;
 T108:;
 	base[1]= symbol_value(VV[21]);
 	base[2]= VV[26];
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk44)();
+	Lformat();
 	vs_top=sup;
 	{register object V50;
 	register object V51;
@@ -318,18 +318,18 @@ T118:;
 	base[3]= symbol_value(VV[21]);
 	base[4]= VV[27];
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk44)();
+	Lformat();
 	vs_top=sup;
-	(void)((*(LnkLI53))((V51)));
+	(void)((*(LnkLI51))((V51)));
 	V50= cdr((V50));
 	V51= car((V50));
 	goto T117;}
 T113:;
-	(void)((*(LnkLI53))(car(symbol_value(VV[6]))));
+	(void)((*(LnkLI51))(car(symbol_value(VV[6]))));
 	base[1]= symbol_value(VV[21]);
 	base[2]= VV[28];
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk44)();
+	Lformat();
 	return;}
 }
 /*	function definition for WT-FASD-DATA-FILE	*/
@@ -348,7 +348,7 @@ TTL:;
 	base[1]= (V52);
 	base[2]= elt(car(symbol_value(VV[25])),1);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk54)();
+	(void) (*Lnk52)();
 	vs_top=sup;
 	V53= caddr(symbol_value(VV[6]));
 	if(((V53))==Cnil){
@@ -365,12 +365,12 @@ T147:;
 	base[2]= small_fixnum(1);
 	base[3]= symbol_value(VV[21]);
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk55)();
+	Lwrite_byte();
 	vs_top=sup;
 	base[2]= (V55);
 	base[3]= car(symbol_value(VV[25]));
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk56)();
+	(void) (*Lnk53)();
 	vs_top=sup;
 	V54= cdr((V54));
 	V55= car((V54));
@@ -379,11 +379,11 @@ T139:;
 	base[1]= (V52);
 	base[2]= car(symbol_value(VV[25]));
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk56)();
+	(void) (*Lnk53)();
 	vs_top=sup;
 	base[1]= car(symbol_value(VV[25]));
 	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk57)();
+	(void) (*Lnk54)();
 	return;}
 }
 /*	local entry for function WT-DATA-BEGIN	*/
@@ -484,7 +484,7 @@ T191:;
 T199:;
 	if(!(endp((V71)))){
 	goto T200;}
-	V73= (VFUN_NARGS=3,(*(LnkLI58))(VV[33],VV[34],car(base[2])));
+	V73= (VFUN_NARGS=3,(*(LnkLI55))(VV[33],VV[34],car(base[2])));
 	V74= list(3,VV[30],/* INLINE-ARGS */V73,VV[5]);
 	V75= make_cons(Cnil,base[3]);
 	base[6]= listA(3,VV[29],/* INLINE-ARGS */V74,reverse(/* INLINE-ARGS */V75));
@@ -555,7 +555,7 @@ T236:;
 T244:;
 	if(!(endp((V84)))){
 	goto T245;}
-	V86= (VFUN_NARGS=3,(*(LnkLI58))(VV[33],VV[38],car(base[2])));
+	V86= (VFUN_NARGS=3,(*(LnkLI55))(VV[33],VV[38],car(base[2])));
 	V87= list(3,VV[30],/* INLINE-ARGS */V86,VV[0]);
 	V88= make_cons(Cnil,base[3]);
 	base[6]= listA(3,VV[29],/* INLINE-ARGS */V87,reverse(/* INLINE-ARGS */V88));
@@ -626,7 +626,7 @@ T281:;
 T289:;
 	if(!(endp((V97)))){
 	goto T290;}
-	V99= (VFUN_NARGS=3,(*(LnkLI58))(VV[33],VV[41],car(base[2])));
+	V99= (VFUN_NARGS=3,(*(LnkLI55))(VV[33],VV[41],car(base[2])));
 	V100= list(3,VV[30],/* INLINE-ARGS */V99,VV[0]);
 	V101= make_cons(Cnil,base[3]);
 	base[6]= listA(3,VV[29],/* INLINE-ARGS */V100,reverse(/* INLINE-ARGS */V101));
@@ -671,19 +671,16 @@ T313:;
 	V105= car((V104));
 	goto T308;}
 }
-static object  LnkTLI58(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[58],&LnkLI58,ap);} /* CONCATENATE */
-static LnkT57(){ call_or_link(VV[57],&Lnk57);} /* CLOSE-FASD */
-static LnkT56(){ call_or_link(VV[56],&Lnk56);} /* WRITE-FASD-TOP */
-static LnkT55(){ call_or_link(VV[55],&Lnk55);} /* WRITE-BYTE */
-static LnkT54(){ call_or_link(VV[54],&Lnk54);} /* FIND-SHARING-TOP */
-static object  LnkTLI53(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[53],&LnkLI53,1,ap);} /* WT-DATA1 */
-static LnkT52(){ call_or_link(VV[52],&Lnk52);} /* WT-FASD-DATA-FILE */
-static object  LnkTLI51(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[51],&LnkLI51,2,ap);} /* COERCE */
-static object  LnkTLI50(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[50],&LnkLI50,1,ap);} /* VERIFY-DATA-VECTOR */
-static object  LnkTLI49(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[49],&LnkLI49,ap);} /* CMPWARN */
-static LnkT48(){ call_or_link(VV[48],&Lnk48);} /* HASH-EQUAL */
-static object  LnkTLI47(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[47],&LnkLI47,ap);} /* VECTOR-PUSH-EXTEND */
-static LnkT46(){ call_or_link(VV[46],&Lnk46);} /* CMPILER-ERROR */
-static LnkT45(){ call_or_link(VV[45],&Lnk45);} /* WT-LOC */
-static LnkT44(){ call_or_link(VV[44],&Lnk44);} /* FORMAT */
-static LnkT43(){ call_or_link(VV[43],&Lnk43);} /* CHAR= */
+static object  LnkTLI55(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[55],&LnkLI55,ap);} /* CONCATENATE */
+static LnkT54(){ call_or_link(VV[54],&Lnk54);} /* CLOSE-FASD */
+static LnkT53(){ call_or_link(VV[53],&Lnk53);} /* WRITE-FASD-TOP */
+static LnkT52(){ call_or_link(VV[52],&Lnk52);} /* FIND-SHARING-TOP */
+static object  LnkTLI51(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[51],&LnkLI51,1,ap);} /* WT-DATA1 */
+static LnkT50(){ call_or_link(VV[50],&Lnk50);} /* WT-FASD-DATA-FILE */
+static object  LnkTLI49(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[49],&LnkLI49,2,ap);} /* COERCE */
+static object  LnkTLI48(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[48],&LnkLI48,1,ap);} /* VERIFY-DATA-VECTOR */
+static object  LnkTLI47(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[47],&LnkLI47,ap);} /* CMPWARN */
+static LnkT46(){ call_or_link(VV[46],&Lnk46);} /* HASH-EQUAL */
+static object  LnkTLI45(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[45],&LnkLI45,ap);} /* VECTOR-PUSH-EXTEND */
+static LnkT44(){ call_or_link(VV[44],&Lnk44);} /* CMPILER-ERROR */
+static LnkT43(){ call_or_link(VV[43],&Lnk43);} /* WT-LOC */
