@@ -38,6 +38,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #define	PAGEWIDTH	11	/*  page width  */
 #endif
 				/*  log2(PAGESIZE)  */
+#undef PAGESIZE
 #define	PAGESIZE	(1 << PAGEWIDTH)	/*  page size in bytes  */
 
 
@@ -129,19 +130,19 @@ struct longfloat_struct {
 
 
 
-#ifdef _MP_H
+/*  #ifdef _MP_H */
 
-#else
-typedef struct
-{
-  int _mp_alloc;		/* Number of *limbs* allocated and pointed
-				   to by the _mp_d field.  */
-  int _mp_size;			/* abs(_mp_size) is the number of limbs the
-				   last field points to.  If _mp_size is
-				   negative this is a negative number.  */
-  void *_mp_d;		/* Pointer to the limbs.  */
-} __mpz_struct;
-#endif
+/*  #else */
+/*  typedef struct */
+/*  { */
+/*    int _mp_alloc;		 Number of *limbs* allocated and pointed  */
+/*  				   to by the _mp_d field.  */
+/*    int _mp_size;			 abs(_mp_size) is the number of limbs the  */
+/*  				   last field points to.  If _mp_size is  */
+/*  				   negative this is a negative number.   */
+/*    void *_mp_d;		 Pointer to the limbs.  */
+/*  } our_mpz_struct; */
+/*  #endif */
 
 struct bignum {
 			FIRSTWORD;
@@ -612,7 +613,7 @@ struct cclosure {		/*  compiled closure header  */
 struct closure {
 	FIRSTWORD; 
 	object	cl_name;       /* name */
-	object	(*cl_self)();  /* C start address of code */
+	int	(*cl_self)();  /* C start address of code */
 	object	cl_data;       /* To object holding VV vector */
 	int cl_argd;           /* description of args + number */
 	int cl_envdim;         /* length of the environment vector */
@@ -622,7 +623,7 @@ struct closure {
 struct sfun {
 		FIRSTWORD; 
 	object	sfn_name;       /* name */
-	object	(*sfn_self)();  /* C start address of code */
+	int	(*sfn_self)();  /* C start address of code */
 	object	sfn_data;       /* To object holding VV vector */
 	int sfn_argd;           /* description of args + number */
 
