@@ -1,5 +1,5 @@
 
-#include <cmpinclude.h>
+#include "cmpinclude.h"
 #include "packlib.h"
 init_packlib(){do_init(VV);}
 /*	macro definition for COERCE-TO-PACKAGE	*/
@@ -22,7 +22,7 @@ static L1()
 T2:;
 	{register object V2;
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V2= vs_base[0];
 	V3= list(2,(V2),base[2]);
@@ -44,7 +44,7 @@ TTL:;
 	V7= symbol_name((V7));
 T5:;
 	vs_base=vs_top;
-	(void) (*Lnk33)();
+	Llist_all_packages();
 	vs_top=sup;
 	V10= vs_base[0];
 	{object V8;
@@ -59,7 +59,7 @@ T9:;
 	base[1]= (V7);
 	base[2]= (V9->c.c_car);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk34)();
+	Lfind_symbol();
 	if(vs_base>=vs_top){vs_top=sup;goto T15;}
 	V13= vs_base[0];
 	vs_base++;
@@ -125,37 +125,37 @@ static L3()
 	object V24;
 	object V25;
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V18= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V19= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V20= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V21= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V22= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V23= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V24= vs_base[0];
 	V25= Cnil;
 	base[6]= base[5];
 	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk35)();
+	(void) (*Lnk32)();
 	if(vs_base<vs_top){
 	V25= vs_base[0];
 	vs_base++;
@@ -220,29 +220,29 @@ static L4()
 	object V48;
 	object V49;
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V44= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V45= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V46= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V47= vs_base[0];
 	vs_base=vs_top;
-	(void) (*Lnk32)();
+	Lgensym();
 	vs_top=sup;
 	V48= vs_base[0];
 	V49= Cnil;
 	base[6]= base[5];
 	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk35)();
+	(void) (*Lnk32)();
 	if(vs_base<vs_top){
 	V49= vs_base[0];
 	vs_base++;
@@ -323,7 +323,7 @@ T50:;
 	base[4]= VV[31];
 	base[5]= number_plus((V70),(V69));
 	vs_top=(vs_base=base+0)+6;
-	(void) (*Lnk36)();
+	Lstring_equal();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T54;}
@@ -343,13 +343,13 @@ TTL:;
 	(void)(prin1((V76),Cnil));
 	base[0]= (V76);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk37)();
+	Lfboundp();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T67;}
 	base[0]= (V76);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk38)();
+	Lspecial_form_p();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T72;}
@@ -358,7 +358,7 @@ TTL:;
 T72:;
 	base[0]= (V76);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk39)();
+	Lmacro_function();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T76;}
@@ -369,13 +369,13 @@ T76:;
 T67:;
 	base[0]= (V76);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk40)();
+	Lboundp();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T79;}
 	base[0]= (V76);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk41)();
+	Lconstantp();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T85;}
@@ -386,7 +386,7 @@ T85:;
 T83:;
 	base[0]= (V76);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk42)();
+	Lsymbol_value();
 	vs_top=sup;
 	V77= vs_base[0];
 	(void)(prin1(V77,Cnil));
@@ -421,7 +421,7 @@ T91:;
 	register object V83;
 	base[2]= V80;
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk3)();
+	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T102;}
@@ -430,7 +430,7 @@ T91:;
 T102:;
 	base[2]= coerce_to_string(V80);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk4)();
+	Lfind_package();
 	vs_top=sup;
 	V81= vs_base[0];
 T100:;
@@ -471,7 +471,7 @@ T115:;
 	base[3]= (V81);
 	base[4]= (V88);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk18)();
+	siLpackage_internal();
 	vs_top=sup;
 	V83= vs_base[0];
 	goto T124;
@@ -480,7 +480,7 @@ T126:;
 	V92 = make_fixnum(V86);
 	base[4]= number_minus((V88),V92);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk19)();
+	siLpackage_external();
 	vs_top=sup;
 	V83= vs_base[0];
 T124:;
@@ -491,9 +491,9 @@ T122:;
 T132:;
 	V82= car((V83));
 	V93= coerce_to_string((V82));
-	if(((*(LnkLI43))((V79),/* INLINE-ARGS */V93))==Cnil){
+	if(((*(LnkLI33))((V79),/* INLINE-ARGS */V93))==Cnil){
 	goto T137;}
-	(void)((*(LnkLI44))((V82)));
+	(void)((*(LnkLI34))((V82)));
 T137:;
 	V83= cdr((V83));
 	goto T122;
@@ -506,7 +506,7 @@ T99:;
 	{object V94;
 	base[2]= (V80);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk45)();
+	Lpackage_use_list();
 	vs_top=sup;
 	V94= vs_base[0];
 T148:;
@@ -521,7 +521,7 @@ T149:;
 	V98= car((V94));
 	base[2]= (V98);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk3)();
+	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T157;}
@@ -530,7 +530,7 @@ T149:;
 T157:;
 	base[2]= coerce_to_string((V98));
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk4)();
+	Lfind_package();
 	vs_top=sup;
 	V95= vs_base[0];}
 T154:;
@@ -553,7 +553,7 @@ T166:;
 	base[3]= (V95);
 	base[4]= (V100);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk19)();
+	siLpackage_external();
 	vs_top=sup;
 	V97= vs_base[0];
 T173:;
@@ -563,9 +563,9 @@ T173:;
 T178:;
 	V96= car((V97));
 	V101= coerce_to_string((V96));
-	if(((*(LnkLI43))((V79),/* INLINE-ARGS */V101))==Cnil){
+	if(((*(LnkLI33))((V79),/* INLINE-ARGS */V101))==Cnil){
 	goto T183;}
-	(void)((*(LnkLI44))((V96)));
+	(void)((*(LnkLI34))((V96)));
 T183:;
 	V97= cdr((V97));
 	goto T173;
@@ -581,7 +581,7 @@ T97:;
 	{object V102;
 	object V103;
 	vs_base=vs_top;
-	(void) (*Lnk33)();
+	Llist_all_packages();
 	vs_top=sup;
 	V102= vs_base[0];
 	V103= car((V102));
@@ -595,7 +595,7 @@ T198:;
 	register object V106;
 	base[4]= V103;
 	vs_top=(vs_base=base+4)+1;
-	(void) (*Lnk3)();
+	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T205;}
@@ -604,7 +604,7 @@ T198:;
 T205:;
 	base[4]= coerce_to_string(V103);
 	vs_top=(vs_base=base+4)+1;
-	(void) (*Lnk4)();
+	Lfind_package();
 	vs_top=sup;
 	V104= vs_base[0];
 T203:;
@@ -645,7 +645,7 @@ T218:;
 	base[5]= (V104);
 	base[6]= (V111);
 	vs_top=(vs_base=base+5)+2;
-	(void) (*Lnk18)();
+	siLpackage_internal();
 	vs_top=sup;
 	V106= vs_base[0];
 	goto T227;
@@ -654,7 +654,7 @@ T229:;
 	V115 = make_fixnum(V109);
 	base[6]= number_minus((V111),V115);
 	vs_top=(vs_base=base+5)+2;
-	(void) (*Lnk19)();
+	siLpackage_external();
 	vs_top=sup;
 	V106= vs_base[0];
 T227:;
@@ -665,9 +665,9 @@ T225:;
 T235:;
 	V105= car((V106));
 	V116= coerce_to_string((V105));
-	if(((*(LnkLI43))((V79),/* INLINE-ARGS */V116))==Cnil){
+	if(((*(LnkLI33))((V79),/* INLINE-ARGS */V116))==Cnil){
 	goto T240;}
-	(void)((*(LnkLI44))((V105)));
+	(void)((*(LnkLI34))((V105)));
 T240:;
 	V106= cdr((V106));
 	goto T225;
@@ -718,7 +718,7 @@ T254:;
 	object V123;
 	base[0]= V119;
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk3)();
+	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T268;}
@@ -727,7 +727,7 @@ T254:;
 T268:;
 	base[0]= coerce_to_string(V119);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk4)();
+	Lfind_package();
 	vs_top=sup;
 	V121= vs_base[0];
 T266:;
@@ -768,7 +768,7 @@ T281:;
 	base[1]= (V121);
 	base[2]= (V128);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk18)();
+	siLpackage_internal();
 	vs_top=sup;
 	V123= vs_base[0];
 	goto T290;
@@ -777,7 +777,7 @@ T292:;
 	V132 = make_fixnum(V126);
 	base[2]= number_minus((V128),V132);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk19)();
+	siLpackage_external();
 	vs_top=sup;
 	V123= vs_base[0];
 T290:;
@@ -788,7 +788,7 @@ T288:;
 T298:;
 	V122= car((V123));
 	V133= coerce_to_string((V122));
-	if(((*(LnkLI43))((V118),/* INLINE-ARGS */V133))==Cnil){
+	if(((*(LnkLI33))((V118),/* INLINE-ARGS */V133))==Cnil){
 	goto T303;}
 	V120= make_cons((V122),(V120));
 T303:;
@@ -803,7 +803,7 @@ T265:;
 	{object V134;
 	base[0]= (V119);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk45)();
+	Lpackage_use_list();
 	vs_top=sup;
 	V134= vs_base[0];
 T315:;
@@ -818,7 +818,7 @@ T316:;
 	V138= car((V134));
 	base[0]= (V138);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk3)();
+	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T324;}
@@ -827,7 +827,7 @@ T316:;
 T324:;
 	base[0]= coerce_to_string((V138));
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk4)();
+	Lfind_package();
 	vs_top=sup;
 	V135= vs_base[0];}
 T321:;
@@ -868,7 +868,7 @@ T337:;
 	base[1]= (V135);
 	base[2]= (V142);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk18)();
+	siLpackage_internal();
 	vs_top=sup;
 	V137= vs_base[0];
 	goto T346;
@@ -877,7 +877,7 @@ T348:;
 	V146 = make_fixnum(V140);
 	base[2]= number_minus((V142),V146);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk19)();
+	siLpackage_external();
 	vs_top=sup;
 	V137= vs_base[0];
 T346:;
@@ -888,7 +888,7 @@ T344:;
 T354:;
 	V136= car((V137));
 	V147= coerce_to_string((V136));
-	if(((*(LnkLI43))((V118),/* INLINE-ARGS */V147))==Cnil){
+	if(((*(LnkLI33))((V118),/* INLINE-ARGS */V147))==Cnil){
 	goto T359;}
 	V120= make_cons((V136),(V120));
 T359:;
@@ -906,7 +906,7 @@ T263:;
 	{object V148;
 	object V149;
 	vs_base=vs_top;
-	(void) (*Lnk33)();
+	Llist_all_packages();
 	vs_top=sup;
 	V148= vs_base[0];
 	V149= car((V148));
@@ -920,7 +920,7 @@ T375:;
 	register object V152;
 	base[2]= V149;
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk3)();
+	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T382;}
@@ -929,7 +929,7 @@ T375:;
 T382:;
 	base[2]= coerce_to_string(V149);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk4)();
+	Lfind_package();
 	vs_top=sup;
 	V150= vs_base[0];
 T380:;
@@ -970,7 +970,7 @@ T395:;
 	base[3]= (V150);
 	base[4]= (V157);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk18)();
+	siLpackage_internal();
 	vs_top=sup;
 	V152= vs_base[0];
 	goto T404;
@@ -979,7 +979,7 @@ T406:;
 	V161 = make_fixnum(V155);
 	base[4]= number_minus((V157),V161);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk19)();
+	siLpackage_external();
 	vs_top=sup;
 	V152= vs_base[0];
 T404:;
@@ -990,7 +990,7 @@ T402:;
 T412:;
 	V151= car((V152));
 	V162= coerce_to_string((V151));
-	if(((*(LnkLI43))((V118),/* INLINE-ARGS */V162))==Cnil){
+	if(((*(LnkLI33))((V118),/* INLINE-ARGS */V162))==Cnil){
 	goto T417;}
 	V120= make_cons((V151),(V120));
 T417:;
@@ -1009,22 +1009,7 @@ T261:;
 	{object V163 = (V120);
 	VMR9(V163)}}}
 	}
-static LnkT45(){ call_or_link(VV[45],&Lnk45);} /* PACKAGE-USE-LIST */
-static object  LnkTLI44(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[44],&LnkLI44,1,ap);} /* PRINT-SYMBOL-APROPOS */
-static object  LnkTLI43(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[43],&LnkLI43,2,ap);} /* SUBSTRINGP */
-static LnkT19(){ call_or_link(VV[19],&Lnk19);} /* PACKAGE-EXTERNAL */
-static LnkT18(){ call_or_link(VV[18],&Lnk18);} /* PACKAGE-INTERNAL */
+static object  LnkTLI34(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[34],&LnkLI34,1,ap);} /* PRINT-SYMBOL-APROPOS */
+static object  LnkTLI33(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[33],&LnkLI33,2,ap);} /* SUBSTRINGP */
 static LnkT10(){ call_or_link(VV[10],&Lnk10);} /* PACKAGE-SIZE */
-static LnkT4(){ call_or_link(VV[4],&Lnk4);} /* FIND-PACKAGE */
-static LnkT3(){ call_or_link(VV[3],&Lnk3);} /* PACKAGEP */
-static LnkT42(){ call_or_link(VV[42],&Lnk42);} /* SYMBOL-VALUE */
-static LnkT41(){ call_or_link(VV[41],&Lnk41);} /* CONSTANTP */
-static LnkT40(){ call_or_link(VV[40],&Lnk40);} /* BOUNDP */
-static LnkT39(){ call_or_link(VV[39],&Lnk39);} /* MACRO-FUNCTION */
-static LnkT38(){ call_or_link(VV[38],&Lnk38);} /* SPECIAL-FORM-P */
-static LnkT37(){ call_or_link(VV[37],&Lnk37);} /* FBOUNDP */
-static LnkT36(){ call_or_link(VV[36],&Lnk36);} /* STRING-EQUAL */
-static LnkT35(){ call_or_link(VV[35],&Lnk35);} /* FIND-DECLARATIONS */
-static LnkT34(){ call_or_link(VV[34],&Lnk34);} /* FIND-SYMBOL */
-static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* LIST-ALL-PACKAGES */
-static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* GENSYM */
+static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* FIND-DECLARATIONS */
