@@ -854,7 +854,7 @@ va_dcl
 
 
 struct key {short n,allow_other_keys;
-	    object *defaults;
+	    iobject *defaults;
 	    iobject keys[1];
 	   };
 
@@ -873,7 +873,7 @@ parse_key_new(n,base,keys,ap)
  /* from here down identical to parse_key_rest */
  new = new + n ;
   {int j=keys->n;
-   object *p= (keys->defaults);
+   object *p= (object *)(keys->defaults);
    while (--j >=0) base[j]=p[j];
  }
  {if (n==0){ return;}
@@ -906,7 +906,7 @@ parse_key_new(n,base,keys,ap)
 	   m -= 2;}
 	if (allow) n = n -2 ; else goto error;}
    }
-  if (n!=0) FEerror("Odd number of keys");
+  if (n!=0) FEerror("Odd number of keys",0);
   return 0;
  error:
   FEerror("Unrecognized key ~a",1,k);
@@ -930,7 +930,7 @@ parse_key_rest(rest,n,base,keys,ap)
     
  new = new + n ;
   {int j=keys->n;
-   object *p= (keys->defaults);
+   object *p= (object *)(keys->defaults);
    while (--j >=0) base[j]=p[j];
  }
  {if (n==0){ return;}
@@ -964,7 +964,7 @@ parse_key_rest(rest,n,base,keys,ap)
 	if (allow) n = n -2 ; else goto error;}
 
    }
-  if (n!=0) FEerror("Odd number of keys");
+  if (n!=0) FEerror("Odd number of keys",0);
   return 0;
  error:
   FEerror("Unrecognized key ~a",1,k);
@@ -977,10 +977,9 @@ set_key_struct(ks,data)
 {int i=ks->n;
  while (--i >=0)
    {ks->keys[i].o =   data->cfd.cfd_self[ ks->keys[i].i ];
-    if (ks->defaults != Cstd_key_defaults)
-     { iobject *def = (iobject *) (ks->defaults);
-       int m=def[i].i;
-        def[i].o=
+    if (ks->defaults != (iobject *)Cstd_key_defaults)
+      {int m=ks->defaults[i].i;
+        ks->defaults[i].o=
 	  (m==-2 ? Cnil :
 	   m==-1 ? (object)0 :
 	   data->cfd.cfd_self[m]);}
