@@ -156,14 +156,17 @@ struct htent *gethash();
 void read_fasd1();
 object extended_read();
 
-#define DEBUG
+/* to enable debugging define the following,
+   and set debug=1 or debug=2
+*/   
+/* #define DEBUG */
 
 #ifdef DEBUG
 
 #define PUT(x) putc1((char)x,fas_stream)
 #define GET() getc1()
-#define FWRITE fwrite1
-#define FREAD fread1
+#define D_FWRITE fwrite1
+#define D_FREAD fread1
 
 char *dump_type_names[]={ "d_nil",
      "d_eval_skip",
@@ -310,8 +313,8 @@ getd(str)
 #define GET() getc(fas_stream)
 #define GET_OP GET
 #define PUT_OP PUT
-#define FWRITE fwrite
-#define FREAD fread
+#define D_FWRITE fwrite
+#define D_FREAD fread
 #define DP(sw)  sw
 #define PUTD(a,b) PUT(b)
 #define GETD(a) GET()
@@ -408,7 +411,7 @@ getd(str)
 
 #define READ_SYMBOL(leng,pack,to) \
 	do { BEGIN_NO_INTERRUPT;{char  *p=alloc_relblock(leng);\
-	 FREAD(p,1,leng,fas_stream); \
+	 D_FREAD(p,1,leng,fas_stream); \
 	 string_register->st.st_fillp = \
 	 string_register->st.st_dim = leng; \
 	 string_register->st.st_self = p; \
@@ -419,7 +422,7 @@ getd(str)
 #define  READ_STRING(leng,loc) do {BEGIN_NO_INTERRUPT;     \
      *loc = alloc_simple_string(leng); \
      (*loc)->st.st_self=alloc_relblock(leng); END_NO_INTERRUPT; \
-  FREAD((*loc)->st.st_self,1,leng,fas_stream);} while(0)
+  D_FREAD((*loc)->st.st_self,1,leng,fas_stream);} while(0)
 
 /* if try_hash finds it we don't need to write the object
    Otherwise we write the index type and the object
@@ -743,7 +746,7 @@ write_fasd(obj)
 	     PUT_OP(d_symbol);
 	     PUT4(j);}
 	   }
-       FWRITE(obj->s.s_self,1,leng,fas_stream);
+       D_FWRITE(obj->s.s_self,1,leng,fas_stream);
        break;
      case DP(t_fixnum:)
        leng=fix(obj);
@@ -769,16 +772,28 @@ write_fasd(obj)
 	 {j=leng;
 	  PUT_OP(d_string);
 	  PUT4(j);}
-       FWRITE(obj->st.st_self,1,leng,fas_stream);
+       D_FWRITE(obj->st.st_self,1,leng,fas_stream);
        break;
      case DP(t_bignum:)
        PUT_OP(d_bignum);
+#ifdef GMP
+     {int l = MP(obj)->_mp_size;
+     int m = (l >= 0 ? l : -l);
+      
+     plong *u = (plong *) MP(obj)->_mp_d;
+     if (sizeof(mp_limb_t) != 4) { FEerror(0,"fix for gmp");}
+     PUT4(l);
+     while (-- m >=0)
+       {PUT4(*u) ; u++;}
+     break;}
+#else     
        {int l = obj->big.big_length;
 	plong *u = obj->big.big_self;
 	PUT4(l);
 	while (-- l >=0)
 	  {PUT4(*u) ; u++;}
        break;}
+#endif       
      case DP(t_package:)
        TRY_HASH;
        PUT_OP(d_package);
@@ -1236,17 +1251,27 @@ read_fasd1(i,loc)
 	 *loc=make_fixnum(j);       
 	 return;}
       case DP( d_bignum:)
-	{int j;
+	{int j,m;
 	 object tem;
 	 plong *u;
 	 GET4(j);
-	 { BEGIN_NO_INTERRUPT;
+#ifdef GMP
+	 tem = new_bignum();
+	 m = (j >= 0 ? j : -j);
+	 _mpz_realloc(MP(tem),m);
+	 MP(tem)->_mp_size = j;
+	 j = m;
+	 u = (plong *) MP(tem)->_mp_d;
+#else	 
+        { BEGIN_NO_INTERRUPT;
 	 tem = alloc_object(t_bignum);
 	 tem->big.big_length = j;
 	 tem-> big.big_self = 0;
 	 u = tem-> big.big_self = (plong *) alloc_relblock(j*sizeof(plong));
 	   END_NO_INTERRUPT;
 	 }
+	
+#endif	 
 	 while ( --j >=0)
 	   { GET4(*u);
 	     u++;}
