@@ -354,6 +354,96 @@ copy_to_big(x)
 }
 
 
+/* put in to get (declare integer working with existing setup.
+   should be optimized at some point, as we're just converting 
+   and reconverting integer data, it appears -- CM */
+
+int
+obj_to_mpz(object x,MP_INT * y) {
+
+  switch(type_of(x)) {
+  case t_fixnum:
+    mpz_set_si(y,fix(x));
+    break;
+  case t_bignum:
+    if (abs(MP(x)->_mp_size)<=y->_mp_alloc)
+      mpz_set(y,MP(x));
+    else
+      return abs(MP(x)->_mp_size)*sizeof(*y->_mp_d);
+    break;
+  default:
+    FEerror("fixnum or bignum expected",0);
+    break;
+  }
+
+  return 0;
+
+}
+
+int
+obj_to_mpz1(object x,MP_INT * y,void *v) {
+
+  switch(type_of(x)) {
+  case t_fixnum:
+    mpz_set_si(y,fix(x));
+    break;
+  case t_bignum:
+    y->_mp_alloc=abs(MP(x)->_mp_size);
+    y->_mp_d=v;
+    mpz_set(y,MP(x));
+    break;
+  default:
+    FEerror("fixnum or bignum expected",0);
+    break;
+  }
+
+  return 0;
+
+}
+
+int
+mpz_to_mpz(MP_INT * x,MP_INT * y) {
+
+  if (abs(x->_mp_size)<=y->_mp_alloc)
+    mpz_set(y,x);
+  else
+    return abs(x->_mp_size)*sizeof(*y->_mp_d);
+
+  return 0;
+
+}
+
+int
+mpz_to_mpz1(MP_INT * x,MP_INT * y,void *v) {
+
+  y->_mp_alloc=abs(x->_mp_size);
+  y->_mp_d=v;
+  mpz_set(y,x);
+  return 0;
+
+}
+
+void
+isetq_fix(MP_INT * var,int s)
+{
+  mpz_set_si(var,s);
+}
+
+MP_INT *
+otoi(object x) {
+  if (type_of(x)==t_fixnum) {
+    object y = new_bignum();
+    mpz_set_si(MP(y),fix(x));
+    return MP(y);
+  }
+  if (type_of(x)==t_bignum)
+    return (MP(x));
+  FEwrong_type_argument(sLinteger,x);
+  return NULL;
+}
+/* end added section for declare integer -- CM */
+
+
 
 
 /* return object like *xpt coercing to a fixnum if necessary,
