@@ -56,6 +56,11 @@ bool saving_system ;
 
 #endif
 
+#if 0
+#ifdef _WIN32
+#include <fcntl.h>
+#endif
+#endif
 
 #define LISP_IMPLEMENTATION_VERSION "April 1994"
 
@@ -83,6 +88,10 @@ object sSAmultiply_stacksA;
 int stack_multiple=1;
 static object stack_space;
 
+#ifdef _WIN32
+unsigned int _dbegin = 0x10100000;
+unsigned int _stacktop, _stackbottom;
+#endif
 
 int cssize;
 
@@ -103,6 +112,7 @@ int argc;
 char **argv, **envp;
 {
 	FILE *i;
+        unsigned int dummy;
 #ifdef BSD
 #ifdef RLIMIT_STACK
 	struct rlimit rl;
@@ -121,9 +131,17 @@ char **argv, **envp;
 	RECREATE_HEAP
 #endif
 	
-	setbuf(stdin, stdin_buf); 
+#ifdef _WIN32
+        _stackbottom = (unsigned int ) &dummy;
+        _stacktop    = _stackbottom - 0x10000; // ???
+#endif
+        setbuf(stdin, stdin_buf); 
 	setbuf(stdout, stdout_buf);
-	
+#if 0        
+#ifdef _WIN32
+	_fmode = _O_BINARY;
+#endif
+#endif
 	ARGC = argc;
 	ARGV = argv;
 #ifdef UNIX
@@ -221,7 +239,7 @@ char **argv, **envp;
 #endif
 #ifdef RLIMIT_STACK
 	getrlimit(RLIMIT_STACK, &rl);
-        if (rl.rlim_cur == RLIM_INFINITY ||
+        if (rl.rlim_cur == RLIM_INFINITY || 
 	    rl.rlim_cur > MAX_STACK_SIZE)
 	  rl.rlim_cur=MAX_STACK_SIZE;
 	cssize = rl.rlim_cur/4 - 4*CSGETA;
@@ -278,6 +296,9 @@ char **argv, **envp;
 
 		v_init_processes();
 		ovm_process_created = 1;
+#endif
+#ifdef HAVE_READLINE
+		init_readline_function();
 #endif
 	      again:
 		super_funcall(sStop_level);
@@ -399,6 +420,14 @@ initlisp()
 	import(Ct, lisp_package);
 	export(Ct, lisp_package);
 
+/*  	Cnil->s.s_hpack = common_lisp_package; */
+	import(Cnil, common_lisp_package);
+	export(Cnil, common_lisp_package);
+
+/*  	Ct->s.s_hpack = common_lisp_package; */
+	import(Ct, common_lisp_package);
+	export(Ct, common_lisp_package);
+
 	sLquote = make_ordinary("QUOTE");
 	sLfunction = make_ordinary("FUNCTION");
 	sLlambda = make_ordinary("LAMBDA");
@@ -575,6 +604,17 @@ va_dcl
 	RETURN(1,int,exit_code, 0); 
 }
 
+DEFUNO("QUIT",int,fLquit,LISP
+   ,0,1,NONE,II,OO,OO,OO,Lquit,"")(va_alist)
+va_dcl
+{	return fLbye(va_alist); }
+ 
+DEFUNO("EXIT",int,fLexit,LISP
+   ,0,1,NONE,II,OO,OO,OO,Lexit,"")(va_alist)
+va_dcl
+{	return fLbye(va_alist); }
+ 
+
 c_trace()
 {
 #ifdef AOSVS
