@@ -107,7 +107,7 @@ int	server;
 		FEerror("No Sockets!",0);
 	}
 
-	if(connect(sock, (char *)&sock_add, sizeof(sock_add)) < 0)
+	if(connect(sock, (const struct sockaddr *)&sock_add, sizeof(sock_add)) < 0)
 	{
 		close(sock);
 		FEerror("Connection Failed.",0);
@@ -316,6 +316,7 @@ init_socket_function()
   make_si_function("RUN-PROCESS", siLrun_process);
 }
 
+#ifdef MUST_USE_STATIC_LINK
 #ifdef __svr4__
 getpagesize()
 { return PAGESIZE;
@@ -336,7 +337,7 @@ dlsym()
 
 
 #endif
-
+#endif
 
 #else /* no RUN_PROCESS */
 
