@@ -19,7 +19,9 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
 
-
+#ifdef __MINGW32__
+#include <sys/types.h>          /* sigset_t */
+#endif
 
 #ifndef IN_UNIXINT
 #include "include.h"
@@ -131,9 +133,9 @@ unblock_sigusr_sigio()
 
 
 void
-sigfpe()
+sigfpe1()
 {
-	gcl_signal(SIGFPE, sigfpe);
+	gcl_signal(SIGFPE, sigfpe1);
 	FEerror("Floating-point exception.", 0);
 }
 sigpipe()
@@ -177,7 +179,7 @@ sigio()
 
 void
 install_default_signals()
-{	gcl_signal(SIGFPE, sigfpe);
+{	gcl_signal(SIGFPE, sigfpe1);
 	gcl_signal(SIGPIPE, sigpipe);
 	gcl_signal(SIGINT, sigint);
 	gcl_signal(SIGUSR1, sigusr1);
